@@ -109,7 +109,7 @@ async fn main() -> Result<()> {
     let conn = Arc::new(UdpSocket::bind(format!("0.0.0.0:{}", port)).await?);
     println!("listening {}...", conn.local_addr()?);
 
-    let mut server = Server::new(ServerConfig {
+    let server = Server::new(ServerConfig {
         conn_configs: vec![ConnConfig {
             conn,
             relay_addr_generator: Box::new(RelayAddressGeneratorStatic {
