@@ -1,15 +1,13 @@
 #[cfg(test)]
 mod peeraddr_test;
 
+use anyhow::Result;
+use std::fmt;
+use std::net::{IpAddr, Ipv4Addr};
 use stun::attributes::*;
 use stun::message::*;
 use stun::xoraddr::*;
 
-use util::Error;
-
-use std::fmt;
-use std::net::{IpAddr, Ipv4Addr};
-
 // PeerAddress implements XOR-PEER-ADDRESS attribute.
 //
 // The XOR-PEER-ADDRESS specifies the address and port of the peer as
@@ -43,7 +41,7 @@ impl fmt::Display for PeerAddress {
 
 impl Setter for PeerAddress {
     // AddTo adds XOR-PEER-ADDRESS to message.
-    fn add_to(&self, m: &mut Message) -> Result<(), Error> {
+    fn add_to(&self, m: &mut Message) -> Result<()> {
         let a = XorMappedAddress {
             ip: self.ip,
             port: self.port,
@@ -54,7 +52,7 @@ impl Setter for PeerAddress {
 
 impl Getter for PeerAddress {
     // GetFrom decodes XOR-PEER-ADDRESS from message.
-    fn get_from(&mut self, m: &Message) -> Result<(), Error> {
+    fn get_from(&mut self, m: &Message) -> Result<()> {
         let mut a = XorMappedAddress::default();
         a.get_from_as(m, ATTR_XOR_PEER_ADDRESS)?;
         self.ip = a.ip;
